==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnServerConfigVpnClientRootCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of VPN client root certificate of VpnServerConfiguration.
 * @property name The certificate name.
 * @property publicCertData The certificate public data.
 */
public data class VpnServerConfigVpnClientRootCertificateArgs(
    public val name: Output<String>? = null,
    public val publicCertData: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs =
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertData(publicCertData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpnServerConfigVpnClientRootCertificateArgs].
 */
@PulumiTagMarker
public class VpnServerConfigVpnClientRootCertificateArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var publicCertData: Output<String>? = null

    /**
     * @param value The certificate name.
     */
    @JvmName("onlshychhepyndrt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("ayymovnickxpxfgh")
    public suspend fun publicCertData(`value`: Output<String>) {
        this.publicCertData = value
    }

    /**
     * @param value The certificate name.
     */
    @JvmName("fgxbcqmycfndxjrp")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("eqpoxjxvtalotymx")
    public suspend fun publicCertData(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertData = mapped
    }

    internal fun build(): VpnServerConfigVpnClientRootCertificateArgs =
        VpnServerConfigVpnClientRootCertificateArgs(
            name = name,
            publicCertData = publicCertData,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VpnServerConfigVpnClientRootCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of VPN client root certificate of VpnServerConfiguration.
 * @property name The certificate name.
 * @property publicCertData The certificate public data.
 */
public data class VpnServerConfigVpnClientRootCertificateArgs(
    public val name: Output<String>? = null,
    public val publicCertData: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs =
        com.pulumi.azurenative.network.inputs.VpnServerConfigVpnClientRootCertificateArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .publicCertData(publicCertData?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpnServerConfigVpnClientRootCertificateArgs].
 */
@PulumiTagMarker
public class VpnServerConfigVpnClientRootCertificateArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var publicCertData: Output<String>? = null

    /**
     * @param value The certificate name.
     */
    @JvmName("citqnotrnddvfmwj")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("eknsklkvgmosodyh")
    public suspend fun publicCertData(`value`: Output<String>) {
        this.publicCertData = value
    }

    /**
     * @param value The certificate name.
     */
    @JvmName("qsbfmgagowghfrnl")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The certificate public data.
     */
    @JvmName("qbgduayaodnbbjvt")
    public suspend fun publicCertData(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicCertData = mapped
    }

    internal fun build(): VpnServerConfigVpnClientRootCertificateArgs =
        VpnServerConfigVpnClientRootCertificateArgs(
            name = name,
            publicCertData = publicCertData,
        )
}
